pub struct GitLabIssueLink {
pub id: Uuid,
pub issue_iid: u64,
pub project_id: Option<u64>,
pub issue_title: String,
pub link_type: GitLabLinkType,
pub notes: Option<String>,
pub created_at: DateTime<Utc>,
pub created_by: Option<String>,
pub last_synced: Option<DateTime<Utc>>,
pub issue_state: Option<String>,
}Expand description
Represents a link between an AIDA requirement and a GitLab issue Used to track traceability between specs and implementation work
Fields
id: UuidUnique identifier for the link
issue_iid: u64GitLab issue IID (project-scoped issue number)
project_id: Option<u64>GitLab project ID (optional - uses default from config if not set)
issue_title: StringDisplay title for the issue (cached from GitLab)
link_type: GitLabLinkTypeType of link between requirement and issue
notes: Option<String>Optional notes about this link
created_at: DateTime<Utc>When this link was created
created_by: Option<String>Who created this link
last_synced: Option<DateTime<Utc>>Last time the issue data was synced from GitLab
issue_state: Option<String>GitLab issue state when last synced (open/closed)
Implementations
Sourceimpl GitLabIssueLink
impl GitLabIssueLink
Sourcepub fn new(issue_iid: u64, issue_title: impl Into<String>) -> GitLabIssueLink
pub fn new(issue_iid: u64, issue_title: impl Into<String>) -> GitLabIssueLink
Creates a new GitLab issue link
Sourcepub fn with_project(self, project_id: u64) -> GitLabIssueLink
pub fn with_project(self, project_id: u64) -> GitLabIssueLink
Sets the project ID
Sourcepub fn with_link_type(self, link_type: GitLabLinkType) -> GitLabIssueLink
pub fn with_link_type(self, link_type: GitLabLinkType) -> GitLabIssueLink
Sets the link type
Sourcepub fn with_creator(self, creator: impl Into<String>) -> GitLabIssueLink
pub fn with_creator(self, creator: impl Into<String>) -> GitLabIssueLink
Sets the creator
Sourcepub fn with_notes(self, notes: impl Into<String>) -> GitLabIssueLink
pub fn with_notes(self, notes: impl Into<String>) -> GitLabIssueLink
Sets notes
Sourcepub fn update_from_issue(&mut self, title: &str, state: &str)
pub fn update_from_issue(&mut self, title: &str, state: &str)
Update sync metadata from GitLab issue
Sourcepub fn display_id(&self) -> String
pub fn display_id(&self) -> String
Returns a display string like “GL-123”